@@ -1,9 +1,16 @@
 "Middleware to inject necessary JS and include device info on the request."
+from __future__ import unicode_literals
 
 import os
 import re
 
-from django.utils.encoding import force_unicode
+from .context_processors import _get_device_type
+
+try:
+    from django.utils.encoding import smart_bytes
+except ImportError:
+    # Django < 1.5 so no Python 3 support
+    smart_bytes = bytes
 
 
 _HTML_TYPES = ('text/html', 'application/xhtml+xml')
@@ -25,19 +32,24 @@ class DeviceInfoMiddleware(object):
                 # TODO: Add logging
                 width = None
                 height = None
-        request.device_info = {'width': width, 'height': height}
+        info = {'width': width, 'height': height}
+        if width is not None:
+            info['type'] =  _get_device_type(width)
+        else:
+            info['type'] = None
+        request.device_info = info
 
     def process_response(self, request, response):
         "Insert necessary javascript to set device info cookie."
         is_gzipped = 'gzip' in response.get('Content-Encoding', '')
         is_html = response.get('Content-Type', '').split(';')[0] in _HTML_TYPES
         if is_html and not is_gzipped:
-            pattern = re.compile(u"<head>", re.IGNORECASE)
+            pattern = re.compile(b'<head>', re.IGNORECASE)
             path = os.path.join(os.path.dirname(__file__), 'static', 'responsive')
             with open(os.path.join(path, 'js', 'responsive.min.js'), 'r') as f:
                 js = f.read()
-            script = u'<script type="text/javascript">{0}</script>'.format(js)
-            response.content = pattern.sub(u"<head>{0}".format(script), force_unicode(response.content))
+            script = b'<script type="text/javascript">' + smart_bytes(js) + b'</script>'
+            response.content = pattern.sub(b'<head>' + script, response.content)
             if response.get('Content-Length', None):
                 response['Content-Length'] = len(response.content)
         return response
